==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/security/kotlin/inputs/DefenderCspmAwsOfferingDatabasesDspmArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.inputs

import com.pulumi.azurenative.security.inputs.DefenderCspmAwsOfferingDatabasesDspmArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The databases DSPM configuration
 * @property cloudRoleArn The cloud role ARN in AWS for this feature
 * @property enabled Is databases DSPM protection enabled
 */
public data class DefenderCspmAwsOfferingDatabasesDspmArgs(
    public val cloudRoleArn: Output<String>? = null,
    public val enabled: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.security.inputs.DefenderCspmAwsOfferingDatabasesDspmArgs> {
    override fun toJava():
        com.pulumi.azurenative.security.inputs.DefenderCspmAwsOfferingDatabasesDspmArgs =
        com.pulumi.azurenative.security.inputs.DefenderCspmAwsOfferingDatabasesDspmArgs.builder()
            .cloudRoleArn(cloudRoleArn?.applyValue({ args0 -> args0 }))
            .enabled(enabled?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DefenderCspmAwsOfferingDatabasesDspmArgs].
 */
@PulumiTagMarker
public class DefenderCspmAwsOfferingDatabasesDspmArgsBuilder internal constructor() {
    private var cloudRoleArn: Output<String>? = null

    private var enabled: Output<Boolean>? = null

    /**
     * @param value The cloud role ARN in AWS for this feature
     */
    @JvmName("yaulenybjriavwvw")
    public suspend fun cloudRoleArn(`value`: Output<String>) {
        this.cloudRoleArn = value
    }

    /**
     * @param value Is databases DSPM protection enabled
     */
    @JvmName("jwssxmxjdaucjebw")
    public suspend fun enabled(`value`: Output<Boolean>) {
        this.enabled = value
    }

    /**
     * @param value The cloud role ARN in AWS for this feature
     */
    @JvmName("cvikksdygjyoljtl")
    public suspend fun cloudRoleArn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cloudRoleArn = mapped
    }

    /**
     * @param value Is databases DSPM protection enabled
     */
    @JvmName("jsqguebkuhnghrmp")
    public suspend fun enabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    internal fun build(): DefenderCspmAwsOfferingDatabasesDspmArgs =
        DefenderCspmAwsOfferingDatabasesDspmArgs(
            cloudRoleArn = cloudRoleArn,
            enabled = enabled,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/security/kotlin/inputs/DefenderCspmAwsOfferingDatabasesDspmArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.inputs

import com.pulumi.azurenative.security.inputs.DefenderCspmAwsOfferingDatabasesDspmArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The databases DSPM configuration
 * @property cloudRoleArn The cloud role ARN in AWS for this feature
 * @property enabled Is databases DSPM protection enabled
 */
public data class DefenderCspmAwsOfferingDatabasesDspmArgs(
    public val cloudRoleArn: Output<String>? = null,
    public val enabled: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.security.inputs.DefenderCspmAwsOfferingDatabasesDspmArgs> {
    override fun toJava():
        com.pulumi.azurenative.security.inputs.DefenderCspmAwsOfferingDatabasesDspmArgs =
        com.pulumi.azurenative.security.inputs.DefenderCspmAwsOfferingDatabasesDspmArgs.builder()
            .cloudRoleArn(cloudRoleArn?.applyValue({ args0 -> args0 }))
            .enabled(enabled?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DefenderCspmAwsOfferingDatabasesDspmArgs].
 */
@PulumiTagMarker
public class DefenderCspmAwsOfferingDatabasesDspmArgsBuilder internal constructor() {
    private var cloudRoleArn: Output<String>? = null

    private var enabled: Output<Boolean>? = null

    /**
     * @param value The cloud role ARN in AWS for this feature
     */
    @JvmName("pajokefbiuclqmnb")
    public suspend fun cloudRoleArn(`value`: Output<String>) {
        this.cloudRoleArn = value
    }

    /**
     * @param value Is databases DSPM protection enabled
     */
    @JvmName("vcfxdpqkpwkphuxm")
    public suspend fun enabled(`value`: Output<Boolean>) {
        this.enabled = value
    }

    /**
     * @param value The cloud role ARN in AWS for this feature
     */
    @JvmName("psnrbyjbebbgkehh")
    public suspend fun cloudRoleArn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cloudRoleArn = mapped
    }

    /**
     * @param value Is databases DSPM protection enabled
     */
    @JvmName("tdgneqtqbmcnbjmp")
    public suspend fun enabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    internal fun build(): DefenderCspmAwsOfferingDatabasesDspmArgs =
        DefenderCspmAwsOfferingDatabasesDspmArgs(
            cloudRoleArn = cloudRoleArn,
            enabled = enabled,
        )
}
